@@ -14,6 +14,7 @@
 
 from __future__ import annotations
 
+import os
 from typing import Optional, Union
 
 from google.adk.agents import LlmAgent, RunConfig
@@ -132,11 +133,17 @@ class Agent(LlmAgent):
                 "You are trying to use your own LiteLLM client, some default request headers may be missing."
             )
 
-        if self.knowledgebase:
-            from veadk.tools import load_knowledgebase_tool
+        self._prepare_tracers()
 
-            load_knowledgebase_tool.knowledgebase = self.knowledgebase
-            self.tools.append(load_knowledgebase_tool.load_knowledgebase_tool)
+        if self.knowledgebase:
+            from veadk.tools.builtin_tools.load_knowledgebase import (
+                LoadKnowledgebaseTool,
+            )
+
+            load_knowledgebase_tool = LoadKnowledgebaseTool(
+                knowledgebase=self.knowledgebase
+            )
+            self.tools.append(load_knowledgebase_tool)
 
         if self.long_term_memory is not None:
             from google.adk.tools import load_memory
@@ -190,6 +197,42 @@ class Agent(LlmAgent):
 
         return final_output
 
+    def _prepare_tracers(self):
+        enable_apmplus_tracer = os.getenv("ENABLE_APMPLUS", "false").lower() == "true"
+        enable_cozeloop_tracer = os.getenv("ENABLE_COZELOOP", "false").lower() == "true"
+        enable_tls_tracer = os.getenv("ENABLE_TLS", "false").lower() == "true"
+
+        if not self.tracers:
+            from veadk.tracing.telemetry.opentelemetry_tracer import OpentelemetryTracer
+
+            self.tracers.append(OpentelemetryTracer())
+
+        exporters = self.tracers[0].exporters  # type: ignore
+
+        from veadk.tracing.telemetry.exporters.apmplus_exporter import APMPlusExporter
+        from veadk.tracing.telemetry.exporters.cozeloop_exporter import CozeloopExporter
+        from veadk.tracing.telemetry.exporters.tls_exporter import TLSExporter
+
+        if enable_apmplus_tracer and not any(
+            isinstance(e, APMPlusExporter) for e in exporters
+        ):
+            self.tracers[0].exporters.append(APMPlusExporter())  # type: ignore
+            logger.info("Enable APMPlus exporter by env.")
+
+        if enable_cozeloop_tracer and not any(
+            isinstance(e, CozeloopExporter) for e in exporters
+        ):
+            self.tracers[0].exporters.append(CozeloopExporter())  # type: ignore
+            logger.info("Enable CozeLoop exporter by env.")
+
+        if enable_tls_tracer and not any(isinstance(e, TLSExporter) for e in exporters):
+            self.tracers[0].exporters.append(TLSExporter())  # type: ignore
+            logger.info("Enable TLS exporter by env.")
+
+        logger.debug(
+            f"Opentelemetry Tracer init {len(self.tracers[0].exporters)} exporters"  # type: ignore
+        )
+
     async def run(
         self,
         prompt: str | list[str],
