@@ -22,7 +22,8 @@ from deepeval.models import LocalModel
 from deepeval.test_case import LLMTestCase
 from deepeval.test_case.llm_test_case import ToolCall
 from typing_extensions import override
-
+from typing import Optional
+from google.adk.evaluation.eval_set import EvalSet
 from veadk.config import getenv
 from veadk.evaluation.base_evaluator import BaseEvaluator, EvalResultData, MetricResult
 from veadk.evaluation.types import EvalResultCaseData, EvalResultMetadata
@@ -77,13 +78,14 @@ class DeepevalEvaluator(BaseEvaluator):
     @override
     async def evaluate(
         self,
-        eval_set_file_path: str,
         metrics: list[BaseMetric],
+        eval_set: Optional[EvalSet] = None,
+        eval_set_file_path: Optional[str] = None,
         eval_id: str = f"test_{formatted_timestamp()}",
     ):
         """Target to Google ADK, we will use the same evaluation case format as Google ADK."""
         # Get evaluation data by parsing eval set file
-        self.build_eval_set(eval_set_file_path)
+        self.build_eval_set(eval_set, eval_set_file_path)
 
         # Get actual data by running agent
         logger.info("Start to run agent for actual data.")
